The answers we want to process are indicated by the character "?". Fill in the
specified answers by generating combinations of the available options to fill
the gaps in order, from value 1 to the maximum number of options available: the
first option for each of the gaps, the second for each of the gaps, and so on.
Usage
set_pending_answers(df)
Value
A data frame.
Arguments
df
A data frame of exercises.
See Also
Other support functions:
create_exercise_csv(),
create_exercise_data_frame(),
create_exercise_excel(),
read_exercise_csv(),
read_exercise_excel(),
vector_to_string(),
write_exercise_csv()